@@ -42,6 +42,8 @@ class TestRecipe(unittest.TestCase):
                                            'bin-directory': self.bin_dir,
                                            'parts-directory': self.parts_dir,
                                            'directory': self.buildout_dir,
+                                           'find-links': '',
+                                           'allow-hosts':'',
                                            },
                               'python-version': {'executable': sys.executable}},
                              'django',
@@ -66,6 +68,8 @@ class TestRecipe(unittest.TestCase):
                                      'bin-directory': self.bin_dir,
                                      'parts-directory': self.parts_dir,
                                      'directory': self.buildout_dir,
+                                     'find-links': '',
+                                     'allow-hosts':'',
                                      },
                         'python-version': {'executable': sys.executable}},
                        'django',
@@ -98,6 +102,10 @@ class TestRecipe(unittest.TestCase):
         # Using a non existent protocol should not be a svn url?
         self.failIf(self.recipe.is_svn_url(
             'unknown://myserver/newforms-admin@7833'))
+        # Using a svn url with spaces
+        self.assert_(self.recipe.is_svn_url(
+            'http://code.djangoproject.com/svn/branches/branch with '
+            'spaces@123'))
 
     def test_command(self):
         # The command method is a wrapper for subprocess which excutes
@@ -472,7 +480,7 @@ class TestRecipe(unittest.TestCase):
                                         'parts/django', False)
         # This should have tried to do a checkout of the Django trunk
         self.assertEqual(command.call_args,
-                         (('svn co http://code.djangoproject.com/svn/django/trunk/ downloads/django-svn -q',), {}))
+                         (('svn co \'http://code.djangoproject.com/svn/django/trunk/\' \'downloads/django-svn\' -q',), {}))
         # A copy command to the parts directory should also have been
         # issued
         self.assertEqual(copytree.call_args,
@@ -492,6 +500,15 @@ class TestRecipe(unittest.TestCase):
         self.assertEqual(command.call_args,
                          (('svn up -q',), {'cwd': 'downloads/django-svn'}))
 
+    @mock.patch('shutil', 'copytree')
+    @mock.patch(Recipe, 'command')
+    def test_install_svn_with_space_in_svn_url(self, copytree, command):
+        self.recipe.install_svn_version('http://www.test.com/s v n/trunk',
+                                        'downloads', 'parts/django', False)
+        self.assertEqual(command.call_args,
+                         (('svn co \'http://www.test.com/s v n/trunk\' \'downloads/django-trunk\' -q',), {}))
+
+
     @mock.patch(Recipe, 'command')
     def test_install_broken_svn(self, command):
         # When the checkout from svn fails during a svn build the
@@ -666,7 +683,9 @@ class TestRecipe(unittest.TestCase):
                                       'bin-directory': self.bin_dir,
                                       'parts-directory': self.parts_dir,
                                       'directory': self.buildout_dir,
-                                     },
+                                      'find-links': '',
+                                      'allow-hosts':'',
+                                      },
                          'python-version': {'executable': '/python4k'}},
                         'django',
                         {'recipe': 'djangorecipe', 'version': 'trunk',
@@ -683,6 +702,8 @@ class TestRecipe(unittest.TestCase):
                                       'bin-directory': self.bin_dir,
                                       'parts-directory': self.parts_dir,
                                       'directory': self.buildout_dir,
+                                      'find-links': '',
+                                      'allow-hosts':'',
                                      },
                          'python-version': {'executable': '/python4k'},
                          'py5k': {'executable': '/python5k'}},
